@@ -13,15 +13,13 @@ class BaseState(metaclass=ABCMeta):
     """
 
     @property
-    def class_name(self):
+    def inst_classname(self) -> str:
         return self.__class__.__name__
 
     @classmethod
-    def classname(cls):
+    def classname(cls) -> str:
         return cls.__name__
 
-    def bla(self_or_cls): # noqa
-        return self_or_cls.__class__.__name__
 
 
 
